% example Quokka3 settingsfile
% HJT unit-cell from A. Fell et al., "Input parameters for the simulation of silicon solar cells in 2014", JPV 2015
%
% (c) 2021 Andreas Fell
%
% uses the simplified 'front and rear contact unit cell' syntax
% correctly accounts for vertical resistance of the aSi-layers (instead of adding it to the lumped Rs value as in the publication)
% slighly lower Voc than in publication mainly due to injection-dependent BGN being considered

Syntax = 'front and rear contact unit cell';

% Solver group
Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'standard';
Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-const';
Solver.Electrical.SkinJ0nieff.Const = 8.27e9;

Thermal.T = 298.15;

% Optical group
Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'HJT_projected_Tfront_bb_scaled.csv'; % these front surface transmission values are already scaled down to account for busbar shading
Optical.TextZ.FrontText.FacetAngle = 53;
Optical.TextZ.FrontZ.Type = 'parameterization'; % the below parameterization is a best-fit to the published optical properties
Optical.TextZ.FrontZ.Z0 = 21.77;
Optical.TextZ.FrontZ.Zinf = 1.264;
Optical.TextZ.FrontZ.Zp = 1;
Optical.ScaleGeneration = 1;

% Bulk group
Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 5;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 1000;
Bulk.Electrical.Recombination.SRH(1).taup = 10000;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;

% ExternalCircuit group
ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.239; % metal only
ExternalCircuit.Rshunt = 1e10;
ExternalCircuit.DiodeJ0 = 0;
ExternalCircuit.DiodeIdeality = 1;

% Syntax specific settings
UnitCellType = 'standard';
CellThickness = 150;

% full area front skin = front i-aSi + p-aSi + TCO stack
FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 150;
FullFrontSkin.Lumped.Electrical.VerticalResistivityEnable = 1;
% FullFrontSkin.Lumped.Electrical.VerticalResistivity.Type = 'ohmic';
FullFrontSkin.Lumped.Electrical.VerticalResistivity.OhmicResistivity = 0.161;
FullFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0(V)';
FullFrontSkin.Lumped.Electrical.ContactedRecombination.J0(V).Type = 'file';
FullFrontSkin.Lumped.Electrical.ContactedRecombination.J0(V).File = 'HJT_J0front.txt';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0(V)';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0(V).Type = 'file';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0(V).File = 'HJT_J0front.txt';

% front contact
FrontContactShape = 'line';
FrontContactWidth = 110;
FrontContactPitch = 1700;
FrontContact.OhmicResistivity = 1e-5;

% front metal
FrontMetalShape = 'H-pattern';
FrontMetalPolarity = 'p-type';
FrontFingerWidth = 110;
FrontFingerShadingFraction = 0.7;

% full area rear skin = rear i-aSi + n-aSi stack
FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 1;
FullRearSkin.Lumped.Electrical.Rsheet = 100;
FullRearSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0(V)';
FullRearSkin.Lumped.Electrical.ContactedRecombination.J0(V).Type = 'file';
FullRearSkin.Lumped.Electrical.ContactedRecombination.J0(V).File = 'HJT_J0rear.txt';

% rear contact
RearContactShape = 'full';
RearContact.OhmicResistivity = 1e-5;

% rear metal
RearMetalShape = 'full';
RearMetalPolarity = 'n-type';
