% example Quokka3 IBC settings file using the generic syntax
% May 2018
% (c) Andreas Fell

% ANU IBC cell design from A. Fell et al., "Input parameters for the simulation of silicon solar cells in 2014", JPV 2015

Syntax = 'generic';

Domain.DeviceType = 'semiconductor device';
Domain.Dimensions = 3;
Domain.Wz = 150;
Domain.Wx = 250;
Domain.Wy = 35;

Solver.SolutionType = 'light JV-curve';
% Solver.SolutionType = 'QE-curve';
Solver.JVCurve.VtermStepSize = 'standard';
% Solver.QECurve.Type = 'biased';
% Solver.QECurve.WavelengthStepSize = 'standard';
% Solver.QECurve.JgenMonochromatic = 0.1;
% Solver.QECurve.Side = 'front';

Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 25 degC;

Thermal.T = 298.15;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 1.5;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 3000;
Bulk.Electrical.Recombination.SRH(1).taup = 3000;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;

ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.051;
ExternalCircuit.Rshunt = 1e5;
ExternalCircuit.DiodeJ0 = 0;
ExternalCircuit.DiodeIdeality = 1;

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'IBC_ANU_Tfront.csv';
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'parameterization';
Optical.TextZ.FrontZ.Z0 = 31;
Optical.TextZ.FrontZ.Zinf = 1.4;
Optical.TextZ.FrontZ.Zp = 2.45;
Optical.ScaleGeneration = 1;

SkinFeature(1).Name = 'front passivation';
SkinFeature(1).Geometry.Plane = 'front';
SkinFeature(1).Geometry.Shape = 'full';
SkinFeature(1).ElectricalModelType = 'lumped';
SkinFeature(1).Lumped.Electrical.RsheetEnable = 0;
SkinFeature(1).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(1).Lumped.Electrical.NonContactedRecombination.J0 = 4.6e-15;

SkinFeature(2).Name = 'rear passivation';
SkinFeature(2).Geometry.Plane = 'rear';
SkinFeature(2).Geometry.Shape = 'full';
SkinFeature(2).ElectricalModelType = 'lumped';
SkinFeature(2).Lumped.Electrical.RsheetEnable = 0;
SkinFeature(2).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(2).Lumped.Electrical.NonContactedRecombination.J0 = 13.1e-15;

SkinFeature(3).Name = 'boron diffusion';
SkinFeature(3).Geometry.Plane = 'rear';
SkinFeature(3).Geometry.Shape = 'rectangle';
SkinFeature(3).Geometry.PositionX = 0; % center coordinates of feature geometry
SkinFeature(3).Geometry.PositionY = 0;
SkinFeature(3).Geometry.SizeX = 330; % full width!
SkinFeature(3).Geometry.SizeY = 70; % full width!
SkinFeature(3).ElectricalModelType = 'lumped';
SkinFeature(3).Lumped.Electrical.ConductionType = 'p-type';
SkinFeature(3).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(3).Lumped.Electrical.Rsheet = 166;
SkinFeature(3).Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
SkinFeature(3).Lumped.Electrical.ContactedRecombination.J0 = 1234e-15;
SkinFeature(3).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(3).Lumped.Electrical.NonContactedRecombination.J0 = 33.2e-15;

SkinFeature(4).Name = 'phosphorus diffusion';
SkinFeature(4).Geometry.Plane = 'rear';
SkinFeature(4).Geometry.Shape = 'rectangle';
SkinFeature(4).Geometry.PositionX = 250; % center coordinates of feature geometry
SkinFeature(4).Geometry.PositionY = 0;
SkinFeature(4).Geometry.SizeX = 23.8; % full width!
SkinFeature(4).Geometry.SizeY = 23.8; % full width!
SkinFeature(4).ElectricalModelType = 'lumped';
SkinFeature(4).Lumped.Electrical.ConductionType = 'n-type';
SkinFeature(4).Lumped.Electrical.RsheetEnable = 1;
SkinFeature(4).Lumped.Electrical.Rsheet = 35;
SkinFeature(4).Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
SkinFeature(4).Lumped.Electrical.ContactedRecombination.J0 = 202e-15;
SkinFeature(4).Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
SkinFeature(4).Lumped.Electrical.NonContactedRecombination.J0 = 176e-15;

ContactFeature(1).Name = 'boron contact';
ContactFeature(1).Geometry.Plane = 'rear';
ContactFeature(1).Geometry.Shape = 'rectangle';
ContactFeature(1).Geometry.PositionX = 0;
ContactFeature(1).Geometry.PositionY = 0;
ContactFeature(1).Geometry.SizeX = 6.2;
ContactFeature(1).Geometry.SizeY = 6.2;
ContactFeature(1).Geometry.RepetitionsX = 2; % two emitter contacts
ContactFeature(1).Geometry.PitchX = 70;
ContactFeature(1).OhmicResistivity = 2e-5;

ContactFeature(2).Name = 'phosphorus contact';
ContactFeature(2).Geometry.Plane = 'rear';
ContactFeature(2).Geometry.Shape = 'rectangle';
ContactFeature(2).Geometry.PositionX = 250;
ContactFeature(2).Geometry.PositionY = 0;
ContactFeature(2).Geometry.SizeX = 6.2;
ContactFeature(2).Geometry.SizeY = 6.2;
ContactFeature(2).OhmicResistivity = 2e-5;

MetalFeature(1).Name = 'p metal';
MetalFeature(1).Geometry.Plane = 'rear';
MetalFeature(1).Geometry.Shape = 'rectangle';
MetalFeature(1).Geometry.PositionX = 0;
MetalFeature(1).Geometry.PositionY = 0;
MetalFeature(1).Geometry.SizeX = 282;
MetalFeature(1).Geometry.SizeY = 70;
MetalFeature(1).Electrical.Polarity = 'p-type';

MetalFeature(2).Name = 'n metal';
MetalFeature(2).Geometry.Plane = 'rear';
MetalFeature(2).Geometry.Shape = 'rectangle';
MetalFeature(2).Geometry.PositionX = 250;
MetalFeature(2).Geometry.PositionY = 0;
MetalFeature(2).Geometry.SizeX = 136;
MetalFeature(2).Geometry.SizeY = 70;
MetalFeature(2).Electrical.Polarity = 'n-type';