% example Quokka3 settingsfile
% PERC unit-cell from A. Fell et al., "Input parameters for the simulation of silicon solar cells in 2014", JPV 2015
%
% (c) 2023 Andreas Fell
%
% uses the skinsolver to simulate the J0 of the passivated front emitter
% from its "detailed skin" properties
%
% this file neglects inactive phosphorus as recombination centers as in the
% main example for simplicity


Syntax = 'generic';

Domain.DeviceType = 'semiconductor skin';

Solver.SolutionType = 'skin single-point';
Solver.Skin.Name = 'passivated front emitter';
Solver.Skin.QFPsplit = 0.55;
Solver.Skin.Jskin = 0;
Solver.Illumination.Enable = 0;

Thermal.T = 298.15;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 2;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 371;
Bulk.Electrical.Recombination.SRH(1).taup = 3710;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;

% full area front skin properties (e.g. front emitter)
SkinFeature(1).Name = 'passivated front emitter';
SkinFeature(1).ElectricalModelType = 'detailed';
SkinFeature(1).Layer(1).Name = 'front diffusion';
SkinFeature(1).Layer(1).Type = 'near-surface';
SkinFeature(1).Layer(1).DopingProfile.DopingType = 'n-type';
SkinFeature(1).Layer(1).DopingProfile.Type = 'file';
SkinFeature(1).Layer(1).DopingProfile.File = 'PERC_DopingProfile_Active.csv';
SkinFeature(1).Layer(1).SurfaceRecombination.Type = 'Si-SiNx-Min2014';

