% example Quokka3 settingsfile
% PERC unit-cell from A. Fell et al., "Input parameters for the simulation of silicon solar cells in 2014", JPV 2015
%
% (c) 2021 Andreas Fell
%
% uses the simplified 'front and rear contact unit cell' syntax
% provides example settings for all solution types


Syntax = 'front and rear contact unit cell';

Solver.SolutionType = 'light JV-curve';
% Solver.SingleJVPoint.Type = 'Jterm';
% Solver.SingleJVPoint.Vintern = 0.7;
% Solver.SingleJVPoint.Vterm = 0.7;
% Solver.SingleJVPoint.Jterm = 30 mA/cm2;

Solver.JVCurve.VtermStepSize = 'coarse';
% Solver.QECurve.WavelengthStepSize = 'standard';
% Solver.QECurve.Type = 'biased';
% Solver.QECurve.Side = 'front';
% Solver.QECurve.JgenMonochromatic = 0.1;
% Solver.RsCurve.VtermStepSize = 'coarse';
% Solver.ELPL.Type = 'PL';
% Solver.Illumination.Enable = 0;

Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-const';
Solver.Electrical.SkinJ0nieff.Const = 8.27e9;

Sweep.Enable = 0;

UnitCellType = 'standard';

CellThickness = 180;
FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontContactPitch = 1700; % pitch of front fingers
FrontFingerWidth = 60; % [m] full width of front fingers
FrontFingerShadingFraction = 0.7;
FrontContactWidth = 60; %[m] full width of contact opening underneath fingers
FrontContact.OhmicResistivity = 2e-3; % [Ohmcm2]

RearContactShape = 'line';
RearMetalShape = 'full';
RearContact.OhmicResistivity = 5e-3; % [Ohmcm2]
% for localized rear contacts only
RearContactPitch = 850;
RearContactWidth = 120; % [m] in case of circular dots, define the size of the square with the same area here

FrontMetalPolarity = 'n-type';
RearMetalPolarity = 'p-type';

Thermal.T = 298.15;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 2;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 371;
Bulk.Electrical.Recombination.SRH(1).taup = 3710;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;

ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.252; % [Ohm.cm2]
ExternalCircuit.Rshunt = 1e10; % [Ohm.cm2]
ExternalCircuit.DiodeJ0 = 0; % [A/cm2]
ExternalCircuit.DiodeIdeality = 1; % []

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'PERC_commercial_Tfront_bb_scaled.csv'; % scaled by busbar shading; must be changed to unscaled Text for busbar-enhanced unit-cell
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'parameterization'; % the below parameterization is a best-fit to the published optical properties
Optical.TextZ.FrontZ.Z0 = 48.25;
Optical.TextZ.FrontZ.Zinf = 1.6;
Optical.TextZ.FrontZ.Zp = 2.229;
Optical.ScaleGeneration = 1;

% Optical.Luminescence.ReabsorptionModelType = 'ideal';


% full area front skin properties (e.g. front emitter)
FullFrontSkin.Geometry.DepthType = 'user';
FullFrontSkin.Geometry.DepthUser = 0.3144;
FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 162;
FullFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 595e-15;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 168e-15;
FullFrontSkin.Lumped.Electrical.EtaColl = 0.95;

% non-contacted rear skin properties (e.g. passivated rear); for localized rear contacts only
FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 0;
FullRearSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.NonContactedRecombination.J0 = 13.1e-15;

% contacted rear skin properties (e.g. Al-BSF)
LocalRearContactSkin.Enable = 1;
LocalRearContactSkin.ElectricalModelType = 'lumped';
LocalRearContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalRearContactSkin.Lumped.Electrical.Rsheet = 61;
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 795e-15;
