% example Quokka3 settingsfile
% conventional unit-cell from A. Fell et al., "Input parameters for the simulation of silicon solar cells in 2014", JPV 2015
%
% (c) 2021 Andreas Fell
%
% uses the simplified 'front and rear contact unit cell' syntax


Syntax = 'front and rear contact unit cell';

Solver.SolutionType = 'light JV-curve';
% Solver.SingleJVPoint.Type = 'MPP';
Solver.JVCurve.VtermStepSize = 'coarse';
% Solver.QECurve.WavelengthStepSize = 'standard';
% Solver.QECurve.Type = 'biased';
% Solver.QECurve.Side = 'front';
% Solver.QECurve.JgenMonochromatic = 0.1;

Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-const';
Solver.Electrical.SkinJ0nieff.Const = 8.27e9;


UnitCellType = 'standard';

CellThickness = 180;
FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontContactPitch = 2.08 mm; % pitch of front fingers
FrontFingerWidth = 60 um; % [m] full width of front fingers
FrontFingerShadingFraction = 0.7;
FrontContactWidth = 60 um; %[m] full width of contact opening underneath fingers
FrontContact.OhmicResistivity = 2e-3; % [Ohmcm2]
RearContactShape = 'full';
RearMetalShape = 'full';
RearContact.OhmicResistivity = 5e-3; % [Ohmcm2]


FrontMetalPolarity = 'n-type';
RearMetalPolarity = 'p-type';

Thermal.T = 25 degC;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 2;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 75;
Bulk.Electrical.Recombination.SRH(1).taup = 75;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;

ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.312; % [Ohm.cm2]
ExternalCircuit.Rshunt = 1e10; % [Ohm.cm2]
ExternalCircuit.DiodeJ0 = 0; % [A/cm2]
ExternalCircuit.DiodeIdeality = 1; % []

Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'conventional_commercial_Tfront_bb_scaled.csv'; % scaled by busbar shading; must be changed to unscaled Text for busbar-enhanced unit-cell
Optical.TextZ.FrontText.FacetAngle = 30;
Optical.TextZ.FrontZ.Type = 'parameterization'; % the below parameterization is a best-fit to the published optical properties
Optical.TextZ.FrontZ.Z0 = 10.51;
Optical.TextZ.FrontZ.Zinf = 1.201;
Optical.TextZ.FrontZ.Zp = 2.55;
Optical.ScaleGeneration = 1;

% full area front skin properties (front emitter)
FullFrontSkin.Geometry.DepthType = 'user';
FullFrontSkin.Geometry.DepthUser = 0.3444;
FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 75;
FullFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 204e-15;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 201e-15;
FullFrontSkin.Lumped.Electrical.EtaColl = 0.85;

% rear skin properties (Al-BSF)
FullRearSkin.Geometry.DepthType = 'user';
FullRearSkin.Geometry.DepthUser = 7;
FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 1;
FullRearSkin.Lumped.Electrical.Rsheet = 30;
FullRearSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.ContactedRecombination.J0 = 517e-15;
FullRearSkin.Lumped.Electrical.EtaColl = 0.7;

