% example Quokka3 settingsfile
% n-PASHA unit-cell from A. Fell et al., "Input parameters for the simulation of silicon solar cells in 2014", JPV 2015
%
% (c) 2021 Andreas Fell
%
% uses the simplified 'front and rear contact unit cell' syntax

Syntax = 'front and rear contact unit cell';

% Solver group
Solver.SolutionType = 'light JV-curve';
Solver.JVCurve.VtermStepSize = 'standard';
Solver.Electrical.MetalModelType = 'constant-potential';
Solver.Electrical.SkinJ0nieff.Type = 'user-const';
Solver.Electrical.SkinJ0nieff.Const = 8.27e9;

Thermal.T = 298.15;

% Optical group
Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'nPASHA_Text_bb_scaled.csv'; % these front surface transmission values are already scaled down to account for busbar shading
Optical.TextZ.FrontText.FacetAngle = 53;
Optical.TextZ.FrontZ.Type = 'parameterization'; % the below parameterization is a best-fit to the published optical properties
Optical.TextZ.FrontZ.Z0 = 12.61;
Optical.TextZ.FrontZ.Zinf = 1.334;
Optical.TextZ.FrontZ.Zp = 1.426;
Optical.ScaleGeneration = 1;

% Bulk group
Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'n-type';
Bulk.BackgroundDoping.Resistivity = 2.7;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 1000;
Bulk.Electrical.Recombination.SRH(1).taup = 1000;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;

% ExternalCircuit group
ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.268;
ExternalCircuit.Rshunt = 1e10;
ExternalCircuit.DiodeJ0 = 0;
ExternalCircuit.DiodeIdeality = 1;

% Syntax specific settings
UnitCellType = 'standard';
CellThickness = 180;

% full area front skin = front p+ emitter
FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 68;
FullFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 1836e-15;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 63e-15;

% front contact
FrontContactShape = 'line';
FrontContactWidth = 45;
FrontContactPitch = 2100;
FrontContact.OhmicResistivity = 1e-3;

% front metal
FrontMetalShape = 'H-pattern';
FrontMetalPolarity = 'p-type';
FrontFingerWidth = 45;
FrontFingerShadingFraction = 0.7;

% full area rear skin = rear n+ diffusion
FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 1;
FullRearSkin.Lumped.Electrical.Rsheet = 171;
FullRearSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.ContactedRecombination.J0 = 1101e-15;
FullRearSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullRearSkin.Lumped.Electrical.NonContactedRecombination.J0 = 103e-15;

% rear contact
RearContactShape = 'line';
RearContactWidth = 100;
RearContactPitch = 1050;
RearContact.OhmicResistivity = 1e-3;

% rear metal
RearMetalShape = 'H-pattern';
RearMetalPolarity = 'n-type';
RearFingerWidth = 100;
RearFingerShadingFraction = 1;
